@@ -11,16 +11,13 @@ use Scalar::Util 'weaken';
 
 has app => sub { Mojo::Server->new->build_app('Mojo::HelloWorld') };
 has 'backend';
-has remove_after => 864000;
-has tasks => sub { {} };
+has missing_after => 86400;
+has remove_after  => 864000;
+has tasks         => sub { {} };
 
-our $VERSION = '1.08';
+our $VERSION = '1.09';
 
-sub add_task {
-  my ($self, $name, $cb) = @_;
-  $self->tasks->{$name} = $cb;
-  return $self;
-}
+sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
 sub enqueue { shift->backend->enqueue(@_) }
 
@@ -119,10 +116,10 @@ web framework with support for multiple backends, such as L<DBM::Deep> and
 L<PostgreSQL|http://www.postgresql.org>.
 
 A job queue allows you to process time and/or computationally intensive tasks
-in background processes, outside of the request/response lifecycle. Among
-those tasks you'll commonly find image resizing, spam filtering, HTTP
-downloads, building tarballs, warming caches and basically everything else you
-can imagine that's not super fast.
+in background processes, outside of the request/response lifecycle. Among those
+tasks you'll commonly find image resizing, spam filtering, HTTP downloads,
+building tarballs, warming caches and basically everything else you can imagine
+that's not super fast.
 
   use Mojolicious::Lite;
 
@@ -132,7 +129,7 @@ can imagine that's not super fast.
   app->minion->add_task(poke_mojo => sub {
     my $job = shift;
     $job->app->ua->get('mojolicio.us');
-    $job->app->log->debug('We have poked mojolicio.us for a visitor.');
+    $job->app->log->debug('We have poked mojolicio.us for a visitor');
   });
 
   # Perform job in a background worker process
@@ -155,6 +152,12 @@ L<Minion::Command::minion::job>.
 
   $ ./myapp.pl minion job
 
+Every job can fail or succeed, but not get lost, the system is eventually
+consistent and will preserve job results for as long as you like, depending on
+L</"remove_after">. While individual workers can fail in the middle of
+processing a job, the system will detect this and ensure that no job is left in
+an uncertain state, depending on L</"missing_after">.
+
 =head1 EVENTS
 
 L<Minion> inherits all events from L<Mojo::EventEmitter> and can emit the
@@ -193,6 +196,15 @@ Application for job queue, defaults to a L<Mojo::HelloWorld> object.
 
 Backend, usually a L<Minion::Backend::File> or L<Minion::Backend::Pg> object.
 
+=head2 missing_after
+
+  my $after = $minion->missing_after;
+  $minion   = $minion->missing_after(172800);
+
+Amount of time in seconds after which workers without a heartbeat will be
+considered missing and removed from the registry by L</"repair">, defaults to
+C<86400> (1 day).
+
 =head2 remove_after
 
   my $after = $minion->remove_after;
@@ -276,9 +288,7 @@ Perform all jobs, very useful for testing.
 
   $minion = $minion->repair;
 
-Repair worker registry and job queue if necessary. All processes running this
-method and workers on this host should be owned by the same user, so they can
-send each other signals to check which workers are still alive.
+Repair worker registry and job queue if necessary.
 
 =head2 reset
 
@@ -298,6 +308,38 @@ Get statistics for jobs and workers.
 
 Build L<Minion::Worker> object.
 
+=head1 REFERENCE
+
+This is the class hierarchy of the L<Minion> distribution.
+
+=over 2
+
+=item * L<Mojolicious::Plugin::Minion>
+
+=item * L<Minion>
+
+=item * L<Minion::Backend>
+
+=over 2
+
+=item * L<Minion::Backend::File>
+
+=item * L<Minion::Backend::Pg>
+
+=back
+
+=item * L<Minion::Command::minion>
+
+=item * L<Minion::Command::minion::job>
+
+=item * L<Minion::Command::minion::worker>
+
+=item * L<Minion::Job>
+
+=item * L<Minion::Worker>
+
+=back
+
 =head1 AUTHOR
 
 Sebastian Riedel, C<sri@cpan.org>.
