@@ -92,8 +92,7 @@ return C<undef> if queue was empty. Meant to be overloaded in a subclass.
   my $job_id = $backend->enqueue(foo => [@args]);
   my $job_id = $backend->enqueue(foo => [@args] => {priority => 1});
 
-Enqueue a new job with C<inactive> state. Meant to be overloaded in a
-subclass.
+Enqueue a new job with C<inactive> state. Meant to be overloaded in a subclass.
 
 These options are currently available:
 
@@ -174,8 +173,10 @@ overloaded in a subclass.
 =head2 register_worker
 
   my $worker_id = $backend->register_worker;
+  my $worker_id = $backend->register_worker($worker_id);
 
-Register worker. Meant to be overloaded in a subclass.
+Register worker or send heartbeat to show that this worker is still alive.
+Meant to be overloaded in a subclass.
 
 =head2 remove_job
 
@@ -201,8 +202,8 @@ Reset job queue. Meant to be overloaded in a subclass.
 
   my $bool = $backend->retry_job($job_id);
 
-Transition from C<failed> or C<finished> state back to C<inactive>. Meant to
-be overloaded in a subclass.
+Transition from C<failed> or C<finished> state back to C<inactive>. Meant to be
+overloaded in a subclass.
 
 =head2 stats
 
