@@ -70,13 +70,16 @@ sub list_workers {
 sub new { shift->SUPER::new(db => DBM::Deep->new(@_)) }
 
 sub register_worker {
-  my $self = shift;
+  my ($self, $id) = @_;
 
   my $db = $self->db;
   $db->lock_exclusive;
-  my $worker
-    = {host => hostname, id => $self->_id, pid => $$, started => time};
-  $self->_workers->{$worker->{id}} = $worker;
+  my $worker = $id ? $self->_workers->{$id} : undef;
+  unless ($worker) {
+    $worker = {host => hostname, id => $self->_id, pid => $$, started => time};
+    $self->_workers->{$worker->{id}} = $worker;
+  }
+  $worker->{notified} = time;
   $db->unlock;
 
   return $worker->{id};
@@ -97,23 +100,23 @@ sub remove_job {
 sub repair {
   my $self = shift;
 
-  # Check workers on this host (all should be owned by the same user)
+  # Check worker registry
   my $db = $self->db;
   $db->lock_exclusive;
   my $workers = $self->_workers;
-  my $host    = hostname;
-  delete $workers->{$_->{id}}
-    for grep { $_->{host} eq $host && !kill 0, $_->{pid} } values %$workers;
+  my $minion  = $self->minion;
+  my $after   = time - $minion->missing_after;
+  $_->{notified} < $after and delete $workers->{$_->{id}} for values %$workers;
 
   # Abandoned jobs
   my $jobs = $self->_jobs;
   for my $job (values %$jobs) {
     next if $job->{state} ne 'active' || $workers->{$job->{worker}};
-    @$job{qw(result state)} = ("Worker not found by $host:$$", 'failed');
+    @$job{qw(finished result state)} = (time, 'Worker went away', 'failed');
   }
 
   # Old jobs
-  my $after = time - $self->minion->remove_after;
+  $after = time - $minion->remove_after;
   delete $jobs->{$_->{id}}
     for grep { $_->{state} eq 'finished' && $_->{finished} < $after }
     values %$jobs;
@@ -131,7 +134,7 @@ sub retry_job {
   if ($job) {
     $job->{retries} += 1;
     @$job{qw(retried state)} = (time, 'inactive');
-    delete $job->{$_} for qw(finished result started worker);
+    delete @$job{qw(finished result started worker)};
   }
   $db->unlock;
 
@@ -141,12 +144,12 @@ sub retry_job {
 sub stats {
   my $self = shift;
 
+  my $active = 0;
   my (%seen, %states);
-  my $active = grep {
-         ++$states{$_->{state}}
-      && $_->{state} eq 'active'
-      && !$seen{$_->{worker}}++
-  } values %{$self->_jobs};
+  for my $job (values %{$self->_jobs}) {
+    $states{$job->{state}}++;
+    $active++ if $job->{state} eq 'active' && !$seen{$job->{worker}}++;
+  }
 
   return {
     active_workers   => $active,
@@ -214,8 +217,9 @@ sub _worker_info {
   my ($self, $id) = @_;
 
   return undef unless $id && (my $worker = $self->_workers->{$id});
-  my @jobs
-    = map { $_->{id} } grep { $_->{worker} eq $id } values %{$self->_jobs};
+  my $jobs = $self->_jobs;
+  my @jobs = map { $_->{id} }
+    grep { $_->{state} eq 'active' && $_->{worker} eq $id } values %$jobs;
   return {%{$worker->export}, jobs => \@jobs};
 }
 
@@ -352,8 +356,9 @@ Construct a new L<Minion::Backend::File> object.
 =head2 register_worker
 
   my $worker_id = $backend->register_worker;
+  my $worker_id = $backend->register_worker($worker_id);
 
-Register worker.
+Register worker or send heartbeat to show that this worker is still alive.
 
 =head2 remove_job
 
