@@ -12,8 +12,7 @@ has usage => sub { shift->extract_usage };
 sub run {
   my ($self, @args) = @_;
 
-  my $args    = [];
-  my $options = {};
+  my ($args, $options) = ([], {});
   GetOptionsFromArray \@args,
     'a|args=s' => sub { $args = decode_json($_[1]) },
     'd|delay=i'    => \$options->{delay},
@@ -78,7 +77,7 @@ sub _list_jobs {
 
 sub _list_workers {
   my $workers = shift->app->minion->backend->list_workers(@_);
-  print tablify [map { [_worker()] } @$workers];
+  print tablify [map { [_worker($_)] } @$workers];
 }
 
 sub _stats {
@@ -92,7 +91,13 @@ sub _stats {
 }
 
 sub _worker {
-  $_->{id}, @{$_->{jobs}} ? 'active' : 'inactive', "$_->{host}:$_->{pid}";
+  my $worker = shift;
+
+  my $state    = @{$worker->{jobs}} ? 'active' : 'inactive';
+  my $name     = $worker->{host} . ':' . $worker->{pid};
+  my $notified = Mojo::Date->new($_->{notified})->to_datetime;
+
+  return $worker->{id}, $state, $name, $notified;
 }
 
 1;
@@ -121,10 +126,10 @@ Minion::Command::minion::job - Minion job command
     -a, --args <JSON array>   Arguments for new job in JSON format
     -d, --delay <seconds>     Delay new job for this many seconds
     -e, --enqueue <name>      New job to be enqueued
-    -l, --limit <number>      Number of jobs/workers to show when listing
-                              them, defaults to 100
-    -o, --offset <number>     Number of jobs/workers to skip when listing
-                              them, defaults to 0
+    -l, --limit <number>      Number of jobs/workers to show when listing them,
+                              defaults to 100
+    -o, --offset <number>     Number of jobs/workers to skip when listing them,
+                              defaults to 0
     -p, --priority <number>   Priority of new job, defaults to 0
     -R, --retry               Retry job
     -r, --remove              Remove job
