@@ -9,7 +9,9 @@ has usage => sub { shift->extract_usage };
 sub run {
   my ($self, @args) = @_;
 
-  GetOptionsFromArray \@args, 't|task=s' => \my @tasks;
+  GetOptionsFromArray \@args,
+    'I|heartbeat-interval=i' => \($self->{interval} = 60),
+    't|task=s' => \my @tasks;
 
   # Limit tasks
   my $app    = $self->app;
@@ -19,22 +21,34 @@ sub run {
 
   local $SIG{INT} = local $SIG{TERM} = sub { $self->{finished}++ };
 
-  my $worker = $minion->worker->register;
-  while (!$self->{finished}) {
-
-    # Repair in regular intervals
-    if (($self->{next} // 0) <= time) {
-      $self->{next} = time + $minion->remove_after;
-      $app->log->debug('Checking worker registry and job queue.')
-        and $minion->repair;
-    }
-
-    # Perform job
-    if (my $job = $worker->dequeue(5)) { $job->perform }
-  }
+  # Log fatal errors
+  my $worker = $self->{worker} = $minion->worker;
+  @$self{qw(register repair)} = (0, 0);
+  eval { $self->_work until $self->{finished}; 1 }
+    or $app->log->fatal("Worker error: $@");
   $worker->unregister;
 }
 
+sub _work {
+  my $self = shift;
+
+  # Send heartbeats in regular intervals
+  $self->{worker}->register and $self->{register} = time + $self->{interval}
+    if $self->{register} < time;
+
+  # Repair in regular intervals
+  if ($self->{repair} < time) {
+    my $app = $self->app;
+    $app->log->debug('Checking worker registry and job queue');
+    my $minion = $app->minion;
+    $minion->repair;
+    $self->{repair} = time + $minion->remove_after;
+  }
+
+  # Perform job
+  if (my $job = $self->{worker}->dequeue(5)) { $job->perform }
+}
+
 1;
 
 =encoding utf8
@@ -48,19 +62,18 @@ Minion::Command::minion::worker - Minion worker command
   Usage: APPLICATION minion worker [OPTIONS]
 
     ./myapp.pl minion worker
-    ./myapp.pl minion worker -m production
+    ./myapp.pl minion worker -m production -I 15
     ./myapp.pl minion worker -t foo -t bar
 
   Options:
-    -t, --task <name>   One or more tasks to handle, defaults to handling all
-                        tasks
+    -I, --heartbeat-interval <seconds>   Heartbeat interval, defaults to 60
+    -t, --task <name>                    One or more tasks to handle, defaults
+                                         to handling all tasks
 
 =head1 DESCRIPTION
 
 L<Minion::Command::minion::worker> starts a L<Minion> worker. You can have as
-many workers as you like, but on every host they should all be owned by the
-same user, so they can send each other signals to check which workers are
-still alive.
+many workers as you like.
 
 =head1 SIGNALS
 
