@@ -36,7 +36,7 @@ Mojolicious::Plugin::Minion - Minion job queue plugin
   app->minion->add_task(slow_log => sub {
     my ($job, $msg) = @_;
     sleep 5;
-    $job->app->log->debug(qq{Received message "$msg".});
+    $job->app->log->debug(qq{Received message "$msg"});
   });
 
   # Start jobs from anywhere in your application
@@ -49,8 +49,8 @@ Mojolicious::Plugin::Minion - Minion job queue plugin
 
 =head1 DESCRIPTION
 
-L<Mojolicious::Plugin::Minion> is a L<Mojolicious> plugin for the L<Minion>
-job queue.
+L<Mojolicious::Plugin::Minion> is a L<Mojolicious> plugin for the L<Minion> job
+queue.
 
 =head1 HELPERS
 
